pub enum PunycodeError {
NotAscii,
Incomplete,
InvalidDigit,
InvalidCodePoint,
}Expand description
An error from decode.
Variants
NotAscii
The input contained a non-ASCII byte (Punycode is ASCII-only).
Incomplete
The extended part ended mid-number.
InvalidDigit
The extended part contained a byte that is not a valid base-36 digit.
InvalidCodePoint
Decoding produced a code point that is not a valid character.